<?php

namespace Bixo\App\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\App\Http\Resources\AppResource;
use Bixo\App\Http\Resources\AppsCollection;
use Bixo\App\Scopes\AppPublicScope;
use Bixo\App\Models\App;

class AppPublicController extends BaseController
{

    /**
     * Show app's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = App::pushScope(new RequestScope())
            ->pushScope(new AppPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $apps = new AppsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('app::app.names'))
            ->view('app::public.app.index')
            ->data(compact('apps', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show app.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = App::findBySlug($slug);
        $data = new AppResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('app::app.name'))
            ->view('app::public.app.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
