<?php

namespace Bixo\App\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\App\Http\Resources\AppResource;
use Bixo\App\Http\Resources\AppsCollection;
use Bixo\App\Scopes\KeyPublicScope;
use Bixo\App\Models\Key;

class KeyPublicController extends BaseController
{

    /**
     * Show key's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Key::pushScope(new RequestScope())
            ->pushScope(new KeyPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $keys = new KeysCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('app::key.names'))
            ->view('app::public.key.index')
            ->data(compact('keys', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show key.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Key::findBySlug($slug);
        $data = new KeyResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('app::key.name'))
            ->view('app::public.key.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
