<?php

namespace Bixo\App\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\App\Events\AppWorkflow as AppWorkflowEvent;
use Bixo\App\Notifications\AppWorkflow as AppWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AppWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AppWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $app is submitted.
     *
     * @param AppWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AppWorkflowEvent $event)
    {
        $client = $event->app->client;
        Notification::send($client, new AppWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $app is published.
     *
     * @param AppWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AppWorkflowEvent $event)
    {
        $client = $event->app->client;
        Notification::send($client, new AppWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $app is approved.
     *
     * @param AppWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AppWorkflowEvent $event)
    {
        $client = $event->app->client;
        Notification::send($client, new AppWorkflowNotification($event));
    }

    /**
     * Handles the $app workflow event as a listener.
     *
     * @param AppWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AppWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
