<?php

namespace Bixo\App\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\App\Events\KeyAction as KeyActionEvent;
use Bixo\App\Notifications\KeyAction as KeyActionNotification;
use Litepie\Actions\Concerns\AsAction;

class KeyAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the KeyActionEvent.
     *
     * @param   KeyActionEvent  $event
     * @return mixed
     */
    public function handle(KeyActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $key.
     *
     * @param   KeyActionEvent  $event
     * @return void
     */
    public function create(KeyActionEvent $event)
    {
        $client = $event->key->client;
        Notification::send($client, new KeyActionNotification($event));
    }

    /**
     * Handle the KeyActionEvent as a listener.
     *
     * @param   KeyActionEvent  $event
     * @return mixed
     */
    public function asListener(KeyActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   KeyActionEvent  $event
     * @return bool
     */
    private function isAllowed(KeyActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
