<?php

namespace Bixo\App\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\App\Events\KeyWorkflow as KeyWorkflowEvent;
use Bixo\App\Notifications\KeyWorkflow as KeyWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class KeyWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(KeyWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $key is submitted.
     *
     * @param KeyWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(KeyWorkflowEvent $event)
    {
        $client = $event->key->client;
        Notification::send($client, new KeyWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $key is published.
     *
     * @param KeyWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(KeyWorkflowEvent $event)
    {
        $client = $event->key->client;
        Notification::send($client, new KeyWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $key is approved.
     *
     * @param KeyWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(KeyWorkflowEvent $event)
    {
        $client = $event->key->client;
        Notification::send($client, new KeyWorkflowNotification($event));
    }

    /**
     * Handles the $key workflow event as a listener.
     *
     * @param KeyWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(KeyWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
