<?php

namespace Bixo\App\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\App\Models\Key;

class KeyPolicy
{

    use KeyWorkflow;

    /**
     * Determine if the given user can view the key.
     *
     * @param Authenticatable $user
     * @param Key $key
     *
     * @return bool
     */
    public function view(Authenticatable $user, Key $key)
    {
        if ($authUser->canDo('app.key.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $key->is_owner;
    }

    /**
     * Determine if the given user can create a key.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('app.key.create');
    }

    /**
     * Determine if the given user can update the given key.
     *
     * @param Authenticatable $user
     * @param Key $key
     *
     * @return bool
     */
    public function update(Authenticatable $user, Key $key)
    {
        if ($user->canDo('app.key.edit') && $user->isAdmin()) {
            return true;
        }

        return $key->is_owner;
    }

    /**
     * Determine if the given user can delete the given key.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Key $key)
    {
        return $key->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
